	SUBROUTINE SC_STBL ( lunstb, iret )
C***********************************************************************
C* SC_STBL                                                             *
C*                                                                     *
C* This subroutine reads the world metar station table, which contains *
C* the station ID, latitude/longitude location, and elevation for each *
C* station in the table.                                               *
C* 								       *
C* SC_STBL ( LUNSTB, IRET )                                            *
C*								       *
C* Input parameters:                                                   *
C*      LUNSTB          INTEGER         Station table unit number      *
C*                                                                     *
C* Output parameters:                                                  *
C*                                                                     *
C*      NSTNS           INTEGER         Number of stations in table    *
C*      ELEV (*)        Real            Station elevation in meters    *
C*      YLAT  (*)       Real            Station latitude in hundredths *
C*                                      of degrees                     *
C*      YLONG (*)       Real            Station latitude in hundredths *
C*                                      of degrees                     *
C*      JSTNID (*)      INTEGER         Array of station ids           *
C*	IRET		INTEGER		return code                    *
C*					  0 = normal return            *
C*					 -2 = station table open error *
C*					                               *
C**								       *
C* Log:                                                                *
C* D. Kidwell/NCEP		10/95				       *
C* R. Hollern/NCEP		 9/97  Switched from the GEMPAK to the *
C*                                     World Metar Station Table       *
C* R. Hollern/NCEP		 7/98  Adapted from MT_STBL            *
C* J. Ator/NCEP			01/05  Added MAXSTN overflow check     *
C***********************************************************************
        INCLUDE         'scstnd.cmn'
C*
	CHARACTER * 100 logstn
C*
        CHARACTER * 4 stid
        CHARACTER * 32 stnnam
        CHARACTER * 2 stat, cntry
	CHARACTER * 14 tbchrs
C-----------------------------------------------------------------------
100     FORMAT ( 'ERROR in processing station table record number', i6 )
C
110     FORMAT ( 1X,I4,3X, A4, 3X, F6.2, 3X, F7.2, 3X, F5.0 )
C
	iret = 0
C
C*	Read in station table.
C
        jret = 0
	nerr = 0
        nstns = 0
C
C*      Station table is in Gempak format.
C
        DO WHILE ( jret .eq. 0 .and. nstns .lt. MAXSTN )
C
           CALL TB_RSTN ( lunstb, stid, stnnam, istnm, stat,
     +                    cntry, slat, slon, selv, ispri, tbchrs, jret )
C
           IF ( jret .eq. 0 ) THEN
               nstns = nstns + 1
               jstnid ( nstns ) = stid
               ylat ( nstns ) = slat
               ylong ( nstns ) = slon
               elev ( nstns ) = selv
C
             ELSE IF ( jret .eq. -1 ) THEN
C
C*             EOF read.
               RETURN
C
             ELSE IF ( jret .eq. -2 ) THEN
C
C*             Read error.
C
               iret = -1
               logstn = ' '
               WRITE ( UNIT = logstn, FMT = 100 ) nstns
               CALL DC_WLOG ( 0, 'DCSCD', 2, logstn(1:53), ierlog )
           END IF
C
         END DO
C*
	RETURN
	END
